@@ -19,7 +19,7 @@ def find_term_match(values: list, term_id: str, default_val={}):
     return next((v for v in values if v.get('term', {}).get('@id') == term_id), default_val)
 
 
-def find_primary_product(cycle: dict):
+def find_primary_product(cycle: dict) -> dict:
     """
     Return the `Product` of a `Cycle` which is set to `primary`, `None` if none present.
 
