@@ -9,7 +9,7 @@ def api_url() -> str: return os.environ.get('API_URL', 'https://api.hestia.earth
 def search_url() -> str: return os.environ.get('SEARCH_URL', 'https://search.hestia.earth')
 
 
-def web_url() -> str: return os.environ.get('WEB_URL', 'https://hestia.earth')
+def web_url() -> str: return os.environ.get('WEB_URL', 'https://www.hestia.earth')
 
 
 def join_args(values) -> str: return '&'.join(list(filter(non_empty_value, values))).strip()
